Crate anne_terminal_input
Source - KeyInputEvent
- A single key input event with key code and order.
- KeyCode
- Re-export portable key code enum from crossterm.
Represents a key.
- disable_raw_mode
- Disable raw terminal mode. Call at application shutdown.
Disables raw mode.
- enable_raw_mode
- Enable raw terminal mode. Call at application start-up.
Enables raw mode.
- handle_event
- Handle a raw terminal event: if it’s a key, insert it into the table.
- input_system
- System that captures raw key input events and writes them to a Table.